@@ -11,11 +11,16 @@ Handles reading and writing data from various types of data files.
 import csv
 
 from .featureset import FeatureSet
-from .readers import (ARFFReader, CSVReader, LibSVMReader, MegaMReader,
-                      NDJReader, TSVReader, safe_float, Reader)
-from .writers import (ARFFWriter, Writer, TSVWriter, CSVWriter,
-                      LibSVMWriter, MegaMWriter, NDJWriter)
-
+from .readers import (
+    ARFFReader,
+    CSVReader,
+    LibSVMReader,
+    NDJReader,
+    Reader,
+    TSVReader,
+    safe_float,
+)
+from .writers import ARFFWriter, CSVWriter, LibSVMWriter, NDJWriter, TSVWriter, Writer
 
 # Register dialect for handling ARFF files
 csv.register_dialect('arff', delimiter=',', quotechar="'",
@@ -24,6 +29,6 @@ csv.register_dialect('arff', delimiter=',', quotechar="'",
 
 
 __all__ = ['Reader', 'safe_float', 'FeatureSet', 'ARFFReader',
-           'CSVReader', 'LibSVMReader', 'MegaMReader', 'NDJReader',
+           'CSVReader', 'LibSVMReader', 'NDJReader',
            'TSVReader', 'ARFFWriter', 'LibSVMWriter', 'TSVWriter',
-           'CSVWriter', 'MegaMWriter', 'NDJWriter', 'Writer']
+           'CSVWriter', 'NDJWriter', 'Writer']
