@@ -137,13 +137,13 @@ class Learner(object):
         A dictionary of keyword arguments to pass to the
         initializer for the specified model.
         Defaults to ``None``.
-    pos_label_str : str, optional
+    pos_label : str, optional
         A string denoting the label of the class to be
         treated as the positive class in a binary classification
         setting. If ``None``, the class represented by the label
         that appears second when sorted is chosen as the positive
         class. For example, if the two labels in data are "A"
-        and "B" and ``pos_label_str`` is not specified, "B" will
+        and "B" and ``pos_label`` is not specified, "B" will
         be chosen as the positive class.
         Defaults to ``None``.
     min_feature_count : int, optional
@@ -176,7 +176,7 @@ class Learner(object):
                  pipeline=False,
                  feature_scaling='none',
                  model_kwargs=None,
-                 pos_label_str=None,
+                 pos_label=None,
                  min_feature_count=1,
                  sampler=None,
                  sampler_kwargs=None,
@@ -191,7 +191,7 @@ class Learner(object):
         self.scaler = None
         self.label_dict = None
         self.label_list = None
-        self.pos_label_str = safe_float(pos_label_str) if pos_label_str is not None else pos_label_str
+        self.pos_label = safe_float(pos_label) if pos_label is not None else pos_label
         self._model = None
         self._store_pipeline = pipeline
         self._feature_scaling = feature_scaling
@@ -264,7 +264,7 @@ class Learner(object):
             self._model_kwargs['max_iter'] = 1000
             self._model_kwargs['tol'] = 1e-3
         elif issubclass(self._model_type, RANSACRegressor):
-            self._model_kwargs['loss'] = 'squared_loss'
+            self._model_kwargs['loss'] = 'squared_error'
         elif issubclass(self._model_type, (MLPClassifier, MLPRegressor)):
             self._model_kwargs['learning_rate'] = 'invscaling'
             self._model_kwargs['max_iter'] = 500
@@ -273,6 +273,23 @@ class Learner(object):
             self._model_kwargs['solver'] = 'liblinear'
             self._model_kwargs['multi_class'] = 'auto'
 
+        #############################################
+        # FIXME when upgrading to scikit-learn v1.2 #
+        #############################################
+        # scikit-learn v1.0 will be deprecating the `normalize`
+        # attribute for linear models; this attribute
+        # is set to False by default in most scikit-learn
+        # linear models anyway and so no warnings are surfaced
+        # in SKLL. However, for `Lars`, the default value of
+        # `normalize` is still set to True and so we need to
+        # force it to False to avoid deprecation warnings. This
+        # code will actually lead to an execption in the
+        # `_create_estimator()` method when the `normalize`
+        # attribute  doesn't exist, so that will be the perfect
+        # reminder to excise this if block entirely.
+        if issubclass(self._model_type, Lars):
+            self._model_kwargs["normalize"] = False
+
         if issubclass(self._model_type,
                       (AdaBoostClassifier, AdaBoostRegressor,
                        DecisionTreeClassifier, DecisionTreeRegressor,
@@ -694,14 +711,14 @@ class Learner(object):
         # that it is last in the list; for multi-class classification
         # raise a warning and set it back to None, since it does not
         # make any sense anyway
-        if self.pos_label_str is not None:
+        if self.pos_label is not None:
             if len(self.label_list) != 2:
-                self.logger.warning('Ignoring value of `pos_label_str` for '
+                self.logger.warning('Ignoring value of `pos_label` for '
                                     'multi-class classification.')
-                self.pos_label_str = None
+                self.pos_label = None
             else:
                 self.label_list = sorted(self.label_list,
-                                         key=lambda x: (x == self.pos_label_str,
+                                         key=lambda x: (x == self.pos_label,
                                                         x))
 
         # Given a list of all labels in the dataset and a list of the
@@ -886,7 +903,7 @@ class Learner(object):
         # Convert to dense if necessary
         if self._use_dense_features:
             try:
-                xtrain = xtrain.todense()
+                xtrain = xtrain.toarray()
             except MemoryError:
                 if issubclass(self._model_type, _REQUIRES_DENSE):
                     reason = (f'{self._model_type.__name__} does not support '
@@ -922,7 +939,7 @@ class Learner(object):
             if isinstance(self.sampler, SkewedChi2Sampler):
                 self.logger.warning('SkewedChi2Sampler uses a dense matrix')
                 if sp.issparse(xtrain):
-                    xtrain = xtrain.todense()
+                    xtrain = xtrain.toarray()
             xtrain = self.sampler.fit_transform(xtrain)
 
         # use label dict transformed version of examples.labels if doing
@@ -1332,7 +1349,7 @@ class Learner(object):
         # Convert to dense if necessary
         if self._use_dense_features and not isinstance(xtest, np.ndarray):
             try:
-                xtest = xtest.todense()
+                xtest = xtest.toarray()
             except MemoryError:
                 if issubclass(self._model_type, _REQUIRES_DENSE):
                     reason = (f'{self._model_type.__name__} does not support '
@@ -1354,7 +1371,7 @@ class Learner(object):
             if isinstance(self.sampler, SkewedChi2Sampler):
                 self.logger.warning('SkewedChi2Sampler uses a dense matrix')
                 if sp.issparse(xtest):
-                    xtest = xtest.todense()
+                    xtest = xtest.toarray()
             xtest = self.sampler.transform(xtest)
 
         # get the various prediction from this learner on these features
@@ -1403,6 +1420,7 @@ class Learner(object):
                        examples,
                        stratified=True,
                        cv_folds=10,
+                       cv_seed=123456789,
                        grid_search=True,
                        grid_search_folds=5,
                        grid_jobs=None,
@@ -1429,6 +1447,12 @@ class Learner(object):
             The number of folds to use for cross-validation, or
             a mapping from example IDs to folds.
             Defaults to 10.
+        cv_seed: int, optional
+            The value for seeding the random number generator
+            used to create the random folds. Note that this
+            seed is *only* used if either ``grid_search`` or
+            ``shuffle`` are set to ``True``.
+            Defaults to 123456789.
         grid_search : bool, optional
             Should we do grid search when training each fold?
             Note: This will make this take *much* longer.
@@ -1506,9 +1530,9 @@ class Learner(object):
             If ``grid_search`` is ``True`` but ``grid_objective`` is ``None``.
         """
 
-        # Seed the random number generator so that randomized algorithms are
-        # replicable.
-        random_state = np.random.RandomState(123456789)
+        # Seed the random number generator so that randomized
+        # algorithms are replicable
+        random_state = np.random.RandomState(cv_seed)
 
         # We need to check whether the labels in the featureset are labels
         # or continuous values. If it's the latter, we need to raise an
